diff mcabber/src/settings.c @ 1272:033576acac4c

Add configurable roster colors (Michal 'vorner' Vaner)
author Mikael Berthe <mikael@lilotux.net>
date Tue, 21 Aug 2007 20:49:03 +0200
parents 9f5c5f176953
children c3107650d165
line wrap: on
line diff
--- a/mcabber/src/settings.c	Mon Aug 20 21:30:16 2007 +0200
+++ b/mcabber/src/settings.c	Tue Aug 21 20:49:03 2007 +0200
@@ -153,15 +153,18 @@
     if ((*line == '\n') || (*line == '\0') || (*line == '#'))
       continue;
 
     // We only allow assignments line, except for commands "pgp" and "source"
     if ((strchr(line, '=') != NULL) ||
-        startswith(line, "pgp ", FALSE) || startswith(line, "source ", FALSE)) {
+        startswith(line, "pgp ", FALSE) || startswith(line, "source ", FALSE) ||
+        startswith(line, "color ", FALSE)) {
       // Only accept the set, alias, bind, pgp and source commands
       if (!startswith(line, "set ", FALSE)   &&
           !startswith(line, "bind ", FALSE)  &&
           !startswith(line, "alias ", FALSE) &&
           !startswith(line, "pgp ", FALSE)   &&
-          !startswith(line, "source ", FALSE)) {
+          !startswith(line, "source ", FALSE) &&
+          !startswith(line, "color ", FALSE)) {
         scr_LogPrint(LPRINT_LOGNORM,
                      "Error in configuration file (l. %d): bad command", ln);
         err++;
@@ -153,15 +153,18 @@
       continue;
 
-    // We only allow assignments line, except for commands "pgp" and "source"
+    // We only allow assignments line, except for commands "pgp", "source"
+    // and "color"
     if ((strchr(line, '=') != NULL) ||